netapp_ontap.resources.dcn_cluster_software_upload API documentation
Description: Copyright &copy; 2025 NetApp Inc. All rights reserved. This file has been automatically generated based on the ONTAP REST API documentation. …

# Module `netapp_ontap.resources.dcn_cluster_software_upload`

Copyright © 2025 NetApp Inc. All rights reserved. This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

You can use this endpoint to upload the DCN software image from the local system to the ONTAP cluster.

### Uploading a software package

The following example shows how to upload a DCN software package.

    import json
    from netapp_ontap import HostConnection
    from netapp_ontap.resources import DcnClusterSoftwareUpload
    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = DcnClusterSoftwareUpload()
        response = resource.upload(file_path="/path/to/image.tgz")
        print(json.dumps(response.http_response.json()), indent=4)

Try it out

    {
        "uuid": "f0ce5ac2-3347-4fa9-9335-ff8f2212bdad",
        "state": "processing",
        "create_time": "2025-07-09T13:27:09-04:00"
    }

## Classes

`class DcnClusterSoftwareUpload (*args, **kwargs)`

  Allows interaction with DcnClusterSoftwarePackage objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def upload (self, file_path, connection: Optional[HostConnection] = None, **kwargs) -> NetAppResponse`

    Upload this file to the host.

    ## Args

    `file_path`
      The path to the file to upload
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`